@@ -3,6 +3,8 @@
 from dataclasses import dataclass
 from urllib.parse import quote
 
+from aiobitrix24.exceptions import BatchError
+
 MAX_BATCH_SIZE = 50
 HALT = 0
 
@@ -16,10 +18,6 @@ class BatchQuery:
     params: dict  # noqa: WPS110
 
 
-class BatchError(Exception):
-    """Rises if batch size is more than 50."""
-
-
 def build_query(query_params: dict, prefix: str = "") -> str:
     """Build complex params row from complex dict.
 
